diff --git a/src/sampling/Make/files b/src/sampling/Make/files
index 9e4a5f1bb4b3f2e9db931f86fcccf5a6a5ec58f4..3029668f8697916bf7b01e63aa3ca8fb6cc00b5c 100644
--- a/src/sampling/Make/files
+++ b/src/sampling/Make/files
@@ -13,10 +13,10 @@ sampledSet/sampledSets/sampledSets.C
 sampledSet/sampledSetsFunctionObject/sampledSetsFunctionObject.C
 
 sampledSet/writers/writer/writers.C
+sampledSet/writers/raw/rawWriters.C
 sampledSet/writers/xmgr/xmgrWriters.C
 sampledSet/writers/gnuplot/gnuplotWriters.C
 sampledSet/writers/jplot/jplotWriters.C
-sampledSet/writers/raw/rawWriters.C
 
 cuttingPlane/cuttingPlane.C
 
diff --git a/src/sampling/sampledSet/writers/gnuplot/gnuplot.H b/src/sampling/sampledSet/writers/gnuplot/gnuplot.H
index 8e0dfd5582770e9fd05005223b9059adea063286..d531ac4aeb67d11d98b4786f71a747e3f2c73e9c 100644
--- a/src/sampling/sampledSet/writers/gnuplot/gnuplot.H
+++ b/src/sampling/sampledSet/writers/gnuplot/gnuplot.H
@@ -63,28 +63,26 @@ public:
         //- Construct null
         gnuplot();
 
-    // Destructor
 
-        virtual ~gnuplot();
+    //- Destructor
+    virtual ~gnuplot();
 
 
     // Member Functions
 
-        // Write
-
-            virtual fileName getFileName
-            (
-                const coordSet&,
-                const wordList&
-            ) const;
-
-            void write
-            (
-                const coordSet&,
-                const wordList&,
-                const List<const Field<Type>*>&,
-                Ostream& os
-            ) const;
+        virtual fileName getFileName
+        (
+            const coordSet&,
+            const wordList&
+        ) const;
+
+        void write
+        (
+            const coordSet&,
+            const wordList&,
+            const List<const Field<Type>*>&,
+            Ostream& os
+        ) const;
 };
 
 
diff --git a/src/sampling/sampledSet/writers/gnuplot/gnuplotWriters.C b/src/sampling/sampledSet/writers/gnuplot/gnuplotWriters.C
index d5e58405c7a503eb5c622f2486f54fba62c01721..7abc5c8fd0bdea26b35858c0d41f24ba88c38f32 100644
--- a/src/sampling/sampledSet/writers/gnuplot/gnuplotWriters.C
+++ b/src/sampling/sampledSet/writers/gnuplot/gnuplotWriters.C
@@ -22,8 +22,6 @@ License
     along with OpenFOAM; if not, write to the Free Software Foundation,
     Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 
-Description
-
 \*---------------------------------------------------------------------------*/
 
 #include "gnuplotWriters.H"
@@ -33,13 +31,7 @@ Description
 
 namespace Foam
 {
-
-// * * * * * * * * * * * * * * Static Data Members * * * * * * * * * * * * * //
-
-makeWriters(gnuplot);
-
-// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //
-
-} // End namespace Foam
+    makeWriters(gnuplot)
+}
 
 // ************************************************************************* //
diff --git a/src/sampling/sampledSet/writers/gnuplot/gnuplotWriters.H b/src/sampling/sampledSet/writers/gnuplot/gnuplotWriters.H
index 4a8a4565764d13b8ff873ffdb43d2886b21c1907..6f125366f24422e96f235849c220ae5d764a601c 100644
--- a/src/sampling/sampledSet/writers/gnuplot/gnuplotWriters.H
+++ b/src/sampling/sampledSet/writers/gnuplot/gnuplotWriters.H
@@ -25,12 +25,9 @@ License
 InClass
     Foam::gnuplotWriters
 
-Description
-
 SourceFiles
     gnuplotWriters.C
 
-
 \*---------------------------------------------------------------------------*/
 
 #ifndef gnuplotWriters_H
@@ -44,16 +41,8 @@ SourceFiles
 
 namespace Foam
 {
-
-// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //
-
-typedef gnuplot<scalar> gnuplotScalarWriter;
-typedef gnuplot<vector> gnuplotVectorWriter;
-typedef gnuplot<tensor> gnuplotTensorWriter;
-
-// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //
-
-} // End namespace Foam
+    makeWritersTypedefs(gnuplot)
+}
 
 // * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //
 
diff --git a/src/sampling/sampledSet/writers/jplot/jplot.H b/src/sampling/sampledSet/writers/jplot/jplot.H
index 3fe254255ae1f2d29b371beb7108b6dabb14737f..45a39ebe161195bcd9215dbf1edd7436eeef141e 100644
--- a/src/sampling/sampledSet/writers/jplot/jplot.H
+++ b/src/sampling/sampledSet/writers/jplot/jplot.H
@@ -25,8 +25,6 @@ License
 Class
     Foam::jplot
 
-Description
-
 SourceFiles
     jplot.C
 
@@ -43,8 +41,6 @@ SourceFiles
 namespace Foam
 {
 
-// Forward declaration of classes
-
 /*---------------------------------------------------------------------------*\
                            Class jplot Declaration
 \*---------------------------------------------------------------------------*/
@@ -71,30 +67,26 @@ public:
         //- Construct null
         jplot();
 
-    // Destructor
 
-        virtual ~jplot();
+    //- Destructor
+    virtual ~jplot();
 
 
     // Member Functions
 
-        // Access
-
-        // Write
-
-            virtual fileName getFileName
-            (
-                const coordSet&,
-                const wordList&
-            ) const;
-
-            void write
-            (
-                const coordSet&,
-                const wordList&,
-                const List<const Field<Type>*>&,
-                Ostream& os
-            ) const;
+        virtual fileName getFileName
+        (
+            const coordSet&,
+            const wordList&
+        ) const;
+
+        void write
+        (
+            const coordSet&,
+            const wordList&,
+            const List<const Field<Type>*>&,
+            Ostream& os
+        ) const;
 };
 
 
diff --git a/src/sampling/sampledSet/writers/jplot/jplotWriters.C b/src/sampling/sampledSet/writers/jplot/jplotWriters.C
index 696f60b579a83c414fe0a732467f4d879f4fdb30..b117178971a3390ce794bb939bd44b9a154b4fd5 100644
--- a/src/sampling/sampledSet/writers/jplot/jplotWriters.C
+++ b/src/sampling/sampledSet/writers/jplot/jplotWriters.C
@@ -22,8 +22,6 @@ License
     along with OpenFOAM; if not, write to the Free Software Foundation,
     Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 
-Description
-
 \*---------------------------------------------------------------------------*/
 
 #include "jplotWriters.H"
@@ -33,13 +31,7 @@ Description
 
 namespace Foam
 {
-
-// * * * * * * * * * * * * * * Static Data Members * * * * * * * * * * * * * //
-
-makeWriters(jplot);
-
-// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //
-
-} // End namespace Foam
+    makeWriters(jplot)
+}
 
 // ************************************************************************* //
diff --git a/src/sampling/sampledSet/writers/jplot/jplotWriters.H b/src/sampling/sampledSet/writers/jplot/jplotWriters.H
index 4971b1ce5dbb9056c8f6a93c88ab4c06011fe98f..21b0121ec02cb926f43552a847df698a5e475b04 100644
--- a/src/sampling/sampledSet/writers/jplot/jplotWriters.H
+++ b/src/sampling/sampledSet/writers/jplot/jplotWriters.H
@@ -25,12 +25,9 @@ License
 InClass
     Foam::jplotWriters
 
-Description
-
 SourceFiles
     jplotWriters.C
 
-
 \*---------------------------------------------------------------------------*/
 
 #ifndef jplotWriters_H
@@ -44,16 +41,8 @@ SourceFiles
 
 namespace Foam
 {
-
-// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //
-
-typedef jplot<scalar> jplotScalarWriter;
-typedef jplot<vector> jplotVectorWriter;
-typedef jplot<tensor> jplotTensorWriter;
-
-// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //
-
-} // End namespace Foam
+    makeWritersTypedefs(jplot)
+}
 
 // * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //
 
diff --git a/src/sampling/sampledSet/writers/raw/raw.H b/src/sampling/sampledSet/writers/raw/raw.H
index e66a7fe83a14933c9e66885992fa094a222559f3..1f4b856f66dfaf916667ea549c661947725591c0 100644
--- a/src/sampling/sampledSet/writers/raw/raw.H
+++ b/src/sampling/sampledSet/writers/raw/raw.H
@@ -64,28 +64,25 @@ public:
         raw();
 
 
-    // Destructor
-
-        virtual ~raw();
+    //- Destructor
+    virtual ~raw();
 
 
     // Member Functions
 
-        // Write
-
-            virtual fileName getFileName
-            (
-                const coordSet&,
-                const wordList&
-            ) const;
-
-            virtual void write
-            (
-                const coordSet&,
-                const wordList&,
-                const List<const Field<Type>*>&,
-                Ostream& os
-            ) const;
+        virtual fileName getFileName
+        (
+            const coordSet&,
+            const wordList&
+        ) const;
+
+        virtual void write
+        (
+            const coordSet&,
+            const wordList&,
+            const List<const Field<Type>*>&,
+            Ostream& os
+        ) const;
 };
 
 
diff --git a/src/sampling/sampledSet/writers/raw/rawWriters.C b/src/sampling/sampledSet/writers/raw/rawWriters.C
index a8bf0df14e42b88949dac570a22cabe3724102b1..0b3a28898cf81c9616e61ae890224bbc9ee9cbfa 100644
--- a/src/sampling/sampledSet/writers/raw/rawWriters.C
+++ b/src/sampling/sampledSet/writers/raw/rawWriters.C
@@ -22,8 +22,6 @@ License
     along with OpenFOAM; if not, write to the Free Software Foundation,
     Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 
-Description
-
 \*---------------------------------------------------------------------------*/
 
 #include "rawWriters.H"
@@ -33,13 +31,7 @@ Description
 
 namespace Foam
 {
-
-// * * * * * * * * * * * * * * Static Data Members * * * * * * * * * * * * * //
-
-makeWriters(raw);
-
-// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //
-
-} // End namespace Foam
+    makeWriters(raw)
+}
 
 // ************************************************************************* //
diff --git a/src/sampling/sampledSet/writers/raw/rawWriters.H b/src/sampling/sampledSet/writers/raw/rawWriters.H
index e121a6dd6f2adf8451ab760c203c8e83b7b4ac01..020b750fe291443767bd9dbe2501fb91d3287cb9 100644
--- a/src/sampling/sampledSet/writers/raw/rawWriters.H
+++ b/src/sampling/sampledSet/writers/raw/rawWriters.H
@@ -25,12 +25,9 @@ License
 InClass
     Foam::rawWriters
 
-Description
-
 SourceFiles
     rawWriters.C
 
-
 \*---------------------------------------------------------------------------*/
 
 #ifndef rawWriters_H
@@ -44,16 +41,8 @@ SourceFiles
 
 namespace Foam
 {
-
-// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //
-
-typedef raw<scalar> rawScalarWriter;
-typedef raw<vector> rawVectorWriter;
-typedef raw<tensor> rawTensorWriter;
-
-// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //
-
-} // End namespace Foam
+    makeWritersTypedefs(raw)
+}
 
 // * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //
 
diff --git a/src/sampling/sampledSet/writers/writer/writer.C b/src/sampling/sampledSet/writers/writer/writer.C
index e629e546f05ef931cf735ee814c0bf70ac7a53c0..b16cbd214f9f70511af3a1cd70e4e77977854e51 100644
--- a/src/sampling/sampledSet/writers/writer/writer.C
+++ b/src/sampling/sampledSet/writers/writer/writer.C
@@ -31,11 +31,11 @@ License
 
 // * * * * * * * * * * * * * * Static Data Members * * * * * * * * * * * * * //
 
-namespace Foam
-{
-
 template<class Type>
-autoPtr<writer<Type> > writer<Type>::New(const word& writeType)
+Foam::autoPtr<Foam::writer<Type> > Foam::writer<Type>::New
+(
+    const word& writeType
+)
 {
     typename wordConstructorTable::iterator cstrIter =
         wordConstructorTablePtr_
@@ -60,7 +60,7 @@ autoPtr<writer<Type> > writer<Type>::New(const word& writeType)
 // * * * * * * * * * * * * * Private Member Functions  * * * * * * * * * * * //
 
 template<class Type>
-fileName writer<Type>::getBaseName
+Foam::fileName Foam::writer<Type>::getBaseName
 (
     const coordSet& points,
     const wordList& valueSets
@@ -78,7 +78,7 @@ fileName writer<Type>::getBaseName
 
 
 template<class Type>
-void writer<Type>::writeCoord
+void Foam::writer<Type>::writeCoord
 (
     const coordSet& points,
     const label pointI,
@@ -97,7 +97,7 @@ void writer<Type>::writeCoord
 
 
 template<class Type>
-void writer<Type>::writeTable
+void Foam::writer<Type>::writeTable
 (
     const coordSet& points,
     const List<Type>& values,
@@ -109,16 +109,14 @@ void writer<Type>::writeTable
         writeCoord(points, pointI, os);
 
         os << token::SPACE;
-
         write(values[pointI], os);
-
         os << endl;
     }
 }
 
 
 template<class Type>
-void writer<Type>::writeTable
+void Foam::writer<Type>::writeTable
 (
     const coordSet& points,
     const List<const List<Type>*>& valuesPtrList,
@@ -132,9 +130,7 @@ void writer<Type>::writeTable
         forAll(valuesPtrList, i)
         {
             os << token::SPACE;
-
             const List<Type>& values = *valuesPtrList[i];
-
             write(values[pointI], os);
         }
         os << endl;
@@ -144,36 +140,44 @@ void writer<Type>::writeTable
 
 // * * * * * * * * * * * * * * * * Constructors  * * * * * * * * * * * * * * //
 
-// Construct null
 template<class Type>
-writer<Type>::writer()
+Foam::writer<Type>::writer()
 {}
 
 
 // * * * * * * * * * * * * * * * * Destructor  * * * * * * * * * * * * * * * //
 
 template<class Type>
-writer<Type>::~writer()
+Foam::writer<Type>::~writer()
 {}
 
 
 // * * * * * * * * * * * * * * * Member Functions  * * * * * * * * * * * * * //
 
 template<class Type>
-Foam::Ostream& Foam::writer<Type>::write(const scalar value, Ostream& os) const
+Foam::Ostream& Foam::writer<Type>::write
+(
+    const scalar value,
+    Ostream& os
+) const
 {
     return os << value;
 }
 
 
 template<class Type>
-Foam::Ostream& Foam::writer<Type>::write(const vector& value, Ostream& os) const
+template<class VSType>
+Foam::Ostream& Foam::writer<Type>::writeVS
+(
+    const VSType& value,
+    Ostream& os
+) const
 {
-    for (direction d=0; d<vector::nComponents; d++)
+    for (direction d=0; d<VSType::nComponents; d++)
     {
         os << value.component(d);
 
-        if (d <= vector::nComponents-1)
+        if (d <= VSType::nComponents-1)
         {
             os << token::TAB;
         }
@@ -183,23 +187,47 @@ Foam::Ostream& Foam::writer<Type>::write(const vector& value, Ostream& os) const
 
 
 template<class Type>
-Foam::Ostream& Foam::writer<Type>::write(const tensor& value, Ostream& os) const
+Foam::Ostream& Foam::writer<Type>::write
+(
+    const vector& value,
+    Ostream& os
+) const
 {
-    for (direction d=0; d<tensor::nComponents; d++)
-    {
-        os << value.component(d);
+    return writeVS(value, os);
+}
 
-        if (d <= tensor::nComponents-1)
-        {
-            os << token::TAB;
-        }
-    }
-    return os;
+
+template<class Type>
+Foam::Ostream& Foam::writer<Type>::write
+(
+    const sphericalTensor& value,
+    Ostream& os
+) const
+{
+    return writeVS(value, os);
+}
+
+
+template<class Type>
+Foam::Ostream& Foam::writer<Type>::write
+(
+    const symmTensor& value,
+    Ostream& os
+) const
+{
+    return writeVS(value, os);
 }
 
 
-// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //
+template<class Type>
+Foam::Ostream& Foam::writer<Type>::write
+(
+    const tensor& value,
+    Ostream& os
+) const
+{
+    return writeVS(value, os);
+}
 
-} // End namespace Foam
 
 // ************************************************************************* //
diff --git a/src/sampling/sampledSet/writers/writer/writers.C b/src/sampling/sampledSet/writers/writer/writers.C
index 9c0598a9f9317278053f622b6537e8833097614d..8aaa5c4127a8f132c7d6bdd17832e8d9e98b51a7 100644
--- a/src/sampling/sampledSet/writers/writer/writers.C
+++ b/src/sampling/sampledSet/writers/writer/writers.C
@@ -22,8 +22,6 @@ License
     along with OpenFOAM; if not, write to the Free Software Foundation,
     Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 
-Description
-
 \*---------------------------------------------------------------------------*/
 
 #include "writers.H"
@@ -35,20 +33,20 @@ namespace Foam
 
 // * * * * * * * * * * * * * * Static Data Members * * * * * * * * * * * * * //
 
-defineNamedTemplateTypeNameAndDebug(scalarWriter, 0);
-defineTemplateRunTimeSelectionTable(scalarWriter, word);
+defineNamedTemplateTypeNameAndDebug(writerScalarWriter, 0);
+defineTemplateRunTimeSelectionTable(writerScalarWriter, word);
 
-defineNamedTemplateTypeNameAndDebug(vectorWriter, 0);
-defineTemplateRunTimeSelectionTable(vectorWriter, word);
+defineNamedTemplateTypeNameAndDebug(writerVectorWriter, 0);
+defineTemplateRunTimeSelectionTable(writerVectorWriter, word);
 
-defineNamedTemplateTypeNameAndDebug(sphericalTensorWriter, 0);
-defineTemplateRunTimeSelectionTable(sphericalTensorWriter, word);
+defineNamedTemplateTypeNameAndDebug(writerSphericalTensorWriter, 0);
+defineTemplateRunTimeSelectionTable(writerSphericalTensorWriter, word);
 
-defineNamedTemplateTypeNameAndDebug(symmTensorWriter, 0);
-defineTemplateRunTimeSelectionTable(symmTensorWriter, word);
+defineNamedTemplateTypeNameAndDebug(writerSymmTensorWriter, 0);
+defineTemplateRunTimeSelectionTable(writerSymmTensorWriter, word);
 
-defineNamedTemplateTypeNameAndDebug(tensorWriter, 0);
-defineTemplateRunTimeSelectionTable(tensorWriter, word);
+defineNamedTemplateTypeNameAndDebug(writerTensorWriter, 0);
+defineTemplateRunTimeSelectionTable(writerTensorWriter, word);
 
 // * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //
 
diff --git a/src/sampling/sampledSet/writers/writer/writers.H b/src/sampling/sampledSet/writers/writer/writers.H
index 49979179d092a13933e510348f07404c2cf16993..ba46c5880a3008e418aeadbcd8d7e5794532089a 100644
--- a/src/sampling/sampledSet/writers/writer/writers.H
+++ b/src/sampling/sampledSet/writers/writer/writers.H
@@ -23,9 +23,10 @@ License
     Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 
 InClass
-    Foam::writer
+    Foam::rawWriters
 
-Description
+SourceFiles
+    writers.C
 
 \*---------------------------------------------------------------------------*/
 
@@ -39,18 +40,8 @@ Description
 
 namespace Foam
 {
-
-// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //
-
-typedef writer<scalar> scalarWriter;
-typedef writer<vector> vectorWriter;
-typedef writer<sphericalTensor> sphericalTensorWriter;
-typedef writer<symmTensor> symmTensorWriter;
-typedef writer<tensor> tensorWriter;
-
-// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //
-
-} // End namespace Foam
+    makeWritersTypedefs(writer)
+}
 
 // * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //
 
diff --git a/src/sampling/sampledSet/writers/xmgr/xmgr.H b/src/sampling/sampledSet/writers/xmgr/xmgr.H
index da4847f61c4662f05b74e1a637ea669f90766c10..4478730fd8560f67d43b9db72b114fe5bba50473 100644
--- a/src/sampling/sampledSet/writers/xmgr/xmgr.H
+++ b/src/sampling/sampledSet/writers/xmgr/xmgr.H
@@ -63,28 +63,26 @@ public:
         //- Construct null
         xmgr();
 
-    // Destructor
 
-        virtual ~xmgr();
+    //- Destructor
+    virtual ~xmgr();
 
 
     // Member Functions
 
-        // Write
-
-            virtual fileName getFileName
-            (
-                const coordSet&,
-                const wordList&
-            ) const;
-
-            void write
-            (
-                const coordSet&,
-                const wordList&,
-                const List<const Field<Type>*>&,
-                Ostream& os
-            ) const;
+        virtual fileName getFileName
+        (
+            const coordSet&,
+            const wordList&
+        ) const;
+
+        void write
+        (
+            const coordSet&,
+            const wordList&,
+            const List<const Field<Type>*>&,
+            Ostream& os
+        ) const;
 };
 
 
diff --git a/src/sampling/sampledSet/writers/xmgr/xmgrWriters.C b/src/sampling/sampledSet/writers/xmgr/xmgrWriters.C
index 451231739340f06c831bed04336ce8938bd21894..90828ad64f7cf4e041fe1362ca073b6a96a7bef1 100644
--- a/src/sampling/sampledSet/writers/xmgr/xmgrWriters.C
+++ b/src/sampling/sampledSet/writers/xmgr/xmgrWriters.C
@@ -22,8 +22,6 @@ License
     along with OpenFOAM; if not, write to the Free Software Foundation,
     Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 
-Description
-
 \*---------------------------------------------------------------------------*/
 
 #include "xmgrWriters.H"
@@ -33,13 +31,7 @@ Description
 
 namespace Foam
 {
-
-// * * * * * * * * * * * * * * Static Data Members * * * * * * * * * * * * * //
-
-makeWriters(xmgr);
-
-// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //
-
-} // End namespace Foam
+    makeWriters(xmgr)
+}
 
 // ************************************************************************* //
diff --git a/src/sampling/sampledSet/writers/xmgr/xmgrWriters.H b/src/sampling/sampledSet/writers/xmgr/xmgrWriters.H
index 1889bfc312b7273c2f955c4009a1e0fd83869e2b..b1b554409a77b3e07cec4a2e84091ea7f916a7ad 100644
--- a/src/sampling/sampledSet/writers/xmgr/xmgrWriters.H
+++ b/src/sampling/sampledSet/writers/xmgr/xmgrWriters.H
@@ -44,16 +44,8 @@ SourceFiles
 
 namespace Foam
 {
-
-// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //
-
-typedef xmgr<scalar> xmgrScalarWriter;
-typedef xmgr<vector> xmgrVectorWriter;
-typedef xmgr<tensor> xmgrTensorWriter;
-
-// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //
-
-} // End namespace Foam
+    makeWritersTypedefs(xmgr)
+}
 
 // * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //
diff --git a/src/sampling/sampledSet/writers/writer/writer.H b/src/sampling/sampledSet/writers/writer/writer.H
index 3751df2f5ee1c6e2261fb093ebc34ee0bcead12c..73fe2fd10fa8f95d181c0400bc03ad221a1cc5b3 100644
--- a/src/sampling/sampledSet/writers/writer/writer.H
+++ b/src/sampling/sampledSet/writers/writer/writer.H
@@ -29,8 +29,8 @@ Description
     Base class for graphics format writing. Entry points are
     - write(..). \n
       Write to an Ostream a table of points with corresponding values.
-    - write(scalar/vector/tensor). \n
-      Write single scalar/vector/tensor.
+    - write(scalar/vector/sphericalTensor/symmTensor/tensor). \n
+      Write single scalar/vector/sphericalTensor/symmTensor/tensor.
       Default is to write space separated components.
 
     Example:
@@ -151,43 +151,47 @@ public:
         writer();
 
 
-    // Destructor
-
-        virtual ~writer() = 0;
+    //- Destructor
+    virtual ~writer() = 0;
 
 
     // Member Functions
 
-        // Access
+        //- Generate file name with correct extension
+        virtual fileName getFileName
+        (
+            const coordSet&,
+            const wordList&
+        ) const = 0;
+
+        //- General entry point for writing.
+        //  The data is organized in a set of point with one or
+        //  more values per point
+        virtual void write
+        (
+            const coordSet&,
+            const wordList&,
+            const List<const Field<Type>*>&,
+            Ostream&
+        ) const = 0;
+
+        //- Write scalar as ascii
+        virtual Ostream& write(const scalar, Ostream&) const;
 
-        // Write
+        template<class VSType>
+        Ostream& writeVS(const VSType& value, Ostream& os) const;
 
-            //- Generate file name with correct extension
-            virtual fileName getFileName
-            (
-                const coordSet&,
-                const wordList&
-            ) const = 0;
-
-            //- General entry point for writing.
-            //  The data is organized in a set of point with one or
-            //  more values per point
-            virtual void write
-            (
-                const coordSet&,
-                const wordList&,
-                const List<const Field<Type>*>&,
-                Ostream&
-            ) const = 0;
+        //- Write vector. Tab separated ascii
+        virtual Ostream& write(const vector&, Ostream&) const;
 
-            //- Write scalar as ascii
-            virtual Ostream& write(const scalar, Ostream&) const;
+        //- Write sphericalTensor. Tab separated ascii
+        virtual Ostream& write(const sphericalTensor&, Ostream&) const;
 
-            //- Write vector. Tab separated ascii
-            virtual Ostream& write(const vector&, Ostream&) const;
+        //- Write symmTensor. Tab separated ascii
+        virtual Ostream& write(const symmTensor&, Ostream&) const;
 
-            //- Write tensor. Tab separated ascii
-            virtual Ostream& write(const tensor&, Ostream&) const;
+        //- Write tensor. Tab separated ascii
+        virtual Ostream& write(const tensor&, Ostream&) const;
 };
 
 
@@ -202,34 +206,47 @@ public:
 #endif
 
 // Only used internally
-#define makeTypeWritersTypeName(type)                       \
-                                                            \
+#define makeTypeWritersTypeName(type)                                         \
+                                                                              \
 defineNamedTemplateTypeNameAndDebug(type, 0);
 
 // Used externally sometimes
-#define makeWritersTypeName(typeWriter)                     \
-                                                            \
-makeTypeWritersTypeName(typeWriter##ScalarWriter);          \
-makeTypeWritersTypeName(typeWriter##VectorWriter);          \
+#define makeWritersTypeName(typeWriter)                                       \
+                                                                              \
+makeTypeWritersTypeName(typeWriter##ScalarWriter);                            \
+makeTypeWritersTypeName(typeWriter##VectorWriter);                            \
+makeTypeWritersTypeName(typeWriter##SphericalTensorWriter);                   \
+makeTypeWritersTypeName(typeWriter##SymmTensorWriter);                        \
 makeTypeWritersTypeName(typeWriter##TensorWriter);
 
 // Define type info for single template instantiation (e.g. vector)
-#define makeWriterTypes(WriterType, type)                   \
-                                                            \
-defineNamedTemplateTypeNameAndDebug(type, 0);               \
-                                                            \
-addToRunTimeSelectionTable                                  \
-(                                                           \
-    WriterType, type, word                                  \
+#define makeWriterTypes(WriterType, type)                                     \
+                                                                              \
+defineNamedTemplateTypeNameAndDebug(type, 0);                                 \
+                                                                              \
+addToRunTimeSelectionTable                                                    \
+(                                                                             \
+    WriterType, type, word                                                    \
 );
 
 
 // Define type info info for scalar, vector etc. instantiations
-#define makeWriters(typeWriter)                             \
-                                                            \
-makeWriterTypes(scalarWriter, typeWriter##ScalarWriter);    \
-makeWriterTypes(vectorWriter, typeWriter##VectorWriter);    \
-makeWriterTypes(tensorWriter, typeWriter##TensorWriter);
+#define makeWriters(typeWriter)                                               \
+                                                                              \
+makeWriterTypes(writerScalarWriter, typeWriter##ScalarWriter);                \
+makeWriterTypes(writerVectorWriter, typeWriter##VectorWriter);                \
+makeWriterTypes(writerSphericalTensorWriter, typeWriter##SphericalTensorWriter);\
+makeWriterTypes(writerSymmTensorWriter, typeWriter##SymmTensorWriter);        \
+makeWriterTypes(writerTensorWriter, typeWriter##TensorWriter);
+
+
+#define makeWritersTypedefs(typeWriter)                                       \
+                                                                              \
+typedef typeWriter<scalar> typeWriter##ScalarWriter;                          \
+typedef typeWriter<vector> typeWriter##VectorWriter;                          \
+typedef typeWriter<sphericalTensor> typeWriter##SphericalTensorWriter;        \
+typedef typeWriter<symmTensor> typeWriter##SymmTensorWriter;                  \
+typedef typeWriter<tensor> typeWriter##TensorWriter;
 
 
 // * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //